@@ -111,7 +111,8 @@ void ggm_bdmcmc_ma( int *iter, int *burnin, int G[], int g_space[], double Ts[],
 			// K_hat_Cpp[i] += K[i] / sum_rates;
 			F77_NAME(daxpy)( &pxp, &weight_C, &K[0], &one, &K_hat_Cpp[0], &one );
 			
-			for( i = 0; i < pxp ; i++ )
+			#pragma omp parallel for
+			for( i = 0; i < pxp; i++ )
 				if( G[i] ) p_links_Cpp[i] += weight_C;
 			
 			sum_weights += weight_C;
@@ -140,6 +141,7 @@ void ggm_bdmcmc_ma( int *iter, int *burnin, int G[], int g_space[], double Ts[],
 	PutRNGstate();
 //-- End of main loop for birth-death MCMC ------------------------------------| 
 
+	#pragma omp parallel for
 	for( i = 0; i < pxp; i++ )
 	{	
 		p_links[i] = p_links_Cpp[i] / sum_weights;
@@ -294,6 +296,7 @@ void ggm_bdmcmc_map( int *iter, int *burnin, int G[], int g_space[], double Ts[]
 	PutRNGstate();
 //-- End of main loop for birth-death MCMC ------------------------------------| 
 
+	#pragma omp parallel for
 	for( i = 0; i < size_sample_graph; i++ ) 
 	{
 		sample_graphs_C[i].copy( sample_graphs[i], qp, 0 );
@@ -302,6 +305,7 @@ void ggm_bdmcmc_map( int *iter, int *burnin, int G[], int g_space[], double Ts[]
 	
 	*size_sample_g = size_sample_graph;
 	
+	#pragma omp parallel for
 	for( i = 0; i < pxp; i++ )
 		K_hat[i] /= sum_weights;
 }
@@ -396,6 +400,7 @@ void ggm_bdmcmc_ma_multi_update( int *iter, int *burnin, int G[], int g_space[],
 			// K_hat_Cpp[i] += K[i] / sum_rates;
 			F77_NAME(daxpy)( &pxp, &weight_C, &K[0], &one, &K_hat_Cpp[0], &one );
 			
+			#pragma omp parallel for
 			for( i = 0; i < pxp ; i++ )
 				if( G[i] ) p_links_Cpp[i] += weight_C;
 			
@@ -431,6 +436,7 @@ void ggm_bdmcmc_ma_multi_update( int *iter, int *burnin, int G[], int g_space[],
 	PutRNGstate();
 //-- End of main loop for birth-death MCMC ------------------------------------| 
 
+	#pragma omp parallel for
 	for( i = 0; i < pxp; i++ )
 	{	
 		p_links[i] = p_links_Cpp[i] / sum_weights;
@@ -554,7 +560,7 @@ void ggm_bdmcmc_map_multi_update( int *iter, int *burnin, int G[], int g_space[]
 			{
 				sample_graphs_C[size_sample_graph] = string_g;
 				graph_weights[size_sample_graph]   = all_weights[count_all_g];
-				all_graphs[count_all_g]          = size_sample_graph; 
+				all_graphs[count_all_g]            = size_sample_graph; 
 				size_sample_graph++;				
 			}
 			
@@ -591,6 +597,7 @@ void ggm_bdmcmc_map_multi_update( int *iter, int *burnin, int G[], int g_space[]
 	PutRNGstate();
 //-- End of main loop for birth-death MCMC ------------------------------------| 
 
+	#pragma omp parallel for
 	for( i = 0; i < ( iteration - burn_in ); i++ ) 
 	{
 		sample_graphs_C[i].copy( sample_graphs[i], qp, 0 );
@@ -600,6 +607,7 @@ void ggm_bdmcmc_map_multi_update( int *iter, int *burnin, int G[], int g_space[]
 	*size_sample_g = size_sample_graph;
 	*counter_all_g = count_all_g;
 	
+	#pragma omp parallel for
 	for( i = 0; i < pxp; i++ ) K_hat[i] /= sum_weights;		
 }
               
